@@ -1,5 +1,8 @@
 package Test::Run::Obj::TotObj;
 
+use strict;
+use warnings;
+
 =head1 NAME
 
 Test::Run::Obj::TotObj - totals encountered for the entire Test::Run session
@@ -58,8 +61,6 @@ sub _initialize
 
     $self->NEXT::_initialize(@_);
 
-    $self->_formatters($self->_formatters() || {});
-
     $self->_register_obj_formatter(
         "fail_no_tests_output",
         "FAILED--%(tests)d test %(_num_scripts)s could be run, alas--no output ever seen\n"
@@ -402,6 +403,8 @@ L<Test::Run::Base::Struct>, L<Test::Run::Obj>, L<Test::Run::Core>
 
 This file is freely distributable under the MIT X11 license.
 
+L<http://www.opensource.org/licenses/mit-license.php>
+
 =head1 AUTHOR
 
 Shlomi Fish, L<http://www.shlomifish.org/>.
